==> pipecat_ai-0.0.40.tar.gz: pipecat_ai-0.0.40/examples/foundational/18a-gstreamer-videotestsrc.py <==
#
# Copyright (c) 2024, Daily
#
# SPDX-License-Identifier: BSD 2-Clause License
#

import asyncio
import aiohttp
import sys

from pipecat.pipeline.pipeline import Pipeline
from pipecat.pipeline.runner import PipelineRunner
from pipecat.pipeline.task import PipelineTask
from pipecat.processors.gstreamer.pipeline_source import GStreamerPipelineSource
from pipecat.transports.services.daily import DailyParams, DailyTransport

from runner import configure

from loguru import logger

from dotenv import load_dotenv
load_dotenv(override=True)

logger.remove(0)
logger.add(sys.stderr, level="DEBUG")


async def main():
    async with aiohttp.ClientSession() as session:
        (room_url, _) = await configure(session)

        transport = DailyTransport(
            room_url,
            None,
            "GStreamer",
            DailyParams(
                camera_out_enabled=True,
                camera_out_width=1280,
                camera_out_height=720,
                camera_out_is_live=True,
            )
        )

        gst = GStreamerPipelineSource(
            pipeline="videotestsrc ! capsfilter caps=\"video/x-raw,width=1280,height=720,framerate=30/1\"",
            out_params=GStreamerPipelineSource.OutputParams(
                video_width=1280,
                video_height=720,
                clock_sync=False))

        pipeline = Pipeline([
            gst,                 # GStreamer file source
            transport.output(),  # Transport bot output
        ])

        task = PipelineTask(pipeline)

        runner = PipelineRunner()

        await runner.run(task)


if __name__ == "__main__":
    asyncio.run(main())

==> pipecat_ai-0.0.44.tar.gz: pipecat_ai-0.0.44/examples/foundational/18a-gstreamer-videotestsrc.py <==
#
# Copyright (c) 2024, Daily
#
# SPDX-License-Identifier: BSD 2-Clause License
#

import asyncio
import aiohttp
import sys

from pipecat.pipeline.pipeline import Pipeline
from pipecat.pipeline.runner import PipelineRunner
from pipecat.pipeline.task import PipelineTask
from pipecat.processors.gstreamer.pipeline_source import GStreamerPipelineSource
from pipecat.transports.services.daily import DailyParams, DailyTransport

from runner import configure

from loguru import logger

from dotenv import load_dotenv

load_dotenv(override=True)

logger.remove(0)
logger.add(sys.stderr, level="DEBUG")


async def main():
    async with aiohttp.ClientSession() as session:
        (room_url, _) = await configure(session)

        transport = DailyTransport(
            room_url,
            None,
            "GStreamer",
            DailyParams(
                camera_out_enabled=True,
                camera_out_width=1280,
                camera_out_height=720,
                camera_out_is_live=True,
            ),
        )

        gst = GStreamerPipelineSource(
            pipeline='videotestsrc ! capsfilter caps="video/x-raw,width=1280,height=720,framerate=30/1"',
            out_params=GStreamerPipelineSource.OutputParams(
                video_width=1280, video_height=720, clock_sync=False
            ),
        )

        pipeline = Pipeline(
            [
                gst,  # GStreamer file source
                transport.output(),  # Transport bot output
            ]
        )

        task = PipelineTask(pipeline)

        runner = PipelineRunner()

        await runner.run(task)


if __name__ == "__main__":
    asyncio.run(main())
